Calculates the taxonomic distinctness (Delta*) from Warwick & Clarke (1995). This is the average weighted path length between individuals of different species only.
References
Warwick, R.M. & Clarke, K.R. (1995). New 'biodiversity' measures reveal a decrease in taxonomic distinctness with increasing stress. Marine Ecology Progress Series, 129, 301-305.
Examples
comm <- c(sp1 = 5, sp2 = 3, sp3 = 3, sp4 = 1, sp5 = 3)
tax <- data.frame(
Species = paste0("sp", 1:5),
Genus = c("G1", "G1", "G2", "G2", "G2"),
Family = c("F1", "F1", "F1", "F2", "F2"),
stringsAsFactors = FALSE
)
delta_star(comm, tax)
#> [1] 1.651163